handler

package
v0.0.0-...-5f4c3c3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 11, 2026 License: MIT Imports: 26 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddTeamMember

func AddTeamMember(c *fiber.Ctx) error

func ArchivePrompt

func ArchivePrompt(c *fiber.Ctx) error

func ArchiveVersion

func ArchiveVersion(c *fiber.Ctx) error

func ChangePassword

func ChangePassword(c *fiber.Ctx) error

func CreateAPIKey

func CreateAPIKey(c *fiber.Ctx) error

func CreateJoinRequest

func CreateJoinRequest(c *fiber.Ctx) error

CreateJoinRequest creates a pending request for the authenticated user to join a specific team.

func CreateOrg

func CreateOrg(c *fiber.Ctx) error

func CreatePrompt

func CreatePrompt(c *fiber.Ctx) error

func CreatePromptPayload

func CreatePromptPayload(c *fiber.Ctx) error

func CreateTeam

func CreateTeam(c *fiber.Ctx) error

func CreateVersion

func CreateVersion(c *fiber.Ctx) error

func DeleteAPIKey

func DeleteAPIKey(c *fiber.Ctx) error

func DeleteMe

func DeleteMe(c *fiber.Ctx) error

func DeleteOrg

func DeleteOrg(c *fiber.Ctx) error

func DeletePromptPayload

func DeletePromptPayload(c *fiber.Ctx) error

func DeleteTeam

func DeleteTeam(c *fiber.Ctx) error

DeleteTeam deletes an existing team.

func DeleteVersion

func DeleteVersion(c *fiber.Ctx) error

func DemoteVersion

func DemoteVersion(c *fiber.Ctx) error

func DiffVersions

func DiffVersions(c *fiber.Ctx) error

func DuplicateVersion

func DuplicateVersion(c *fiber.Ctx) error

func GenerateVerificationCode

func GenerateVerificationCode() (string, error)

func GetAdminInbox

func GetAdminInbox(c *fiber.Ctx) error

GetAdminInbox returns all pending join requests that the caller is authorized to approve or reject.

func GetPrompt

func GetPrompt(c *fiber.Ctx) error

func GetPromptPayload

func GetPromptPayload(c *fiber.Ctx) error

func GetVersion

func GetVersion(c *fiber.Ctx) error

func Health

func Health(c *fiber.Ctx) error

func IsOrgAdmin

func IsOrgAdmin(c *fiber.Ctx, orgID uuid.UUID) (bool, error)

func IsTeamAdmin

func IsTeamAdmin(c *fiber.Ctx, teamID uuid.UUID) (bool, error)

func IsTeamEditor

func IsTeamEditor(c *fiber.Ctx, teamID uuid.UUID) (bool, error)

func IsTeamViewer

func IsTeamViewer(c *fiber.Ctx, teamID uuid.UUID) (bool, error)

func LeaveTeam

func LeaveTeam(c *fiber.Ctx) error

func ListAPIKeys

func ListAPIKeys(c *fiber.Ctx) error

func ListAllPrompts

func ListAllPrompts(c *fiber.Ctx) error

func ListOrgPeople

func ListOrgPeople(c *fiber.Ctx) error

func ListOrgTeams

func ListOrgTeams(c *fiber.Ctx) error

ListOrgTeams lists all teams within a specific organization. Anyone belonging to that organization can see the teams.

func ListPromptPayloads

func ListPromptPayloads(c *fiber.Ctx) error

func ListPrompts

func ListPrompts(c *fiber.Ctx) error

func ListTags

func ListTags(c *fiber.Ctx) error

func ListTeamMembers

func ListTeamMembers(c *fiber.Ctx) error

func ListUserOrgs

func ListUserOrgs(c *fiber.Ctx) error

func ListUserTeams

func ListUserTeams(c *fiber.Ctx) error

func ListVersions

func ListVersions(c *fiber.Ctx) error

func Login

func Login(c *fiber.Ctx) error

func Logout

func Logout(c *fiber.Ctx) error

func Me

func Me(c *fiber.Ctx) error

func MovePrompt

func MovePrompt(c *fiber.Ctx) error

func NormalizeSlug

func NormalizeSlug(s string) string

func PromoteVersion

func PromoteVersion(c *fiber.Ctx) error

func Register

func Register(c *fiber.Ctx) error

func RemoveOrgMember

func RemoveOrgMember(c *fiber.Ctx) error

func RemoveTag

func RemoveTag(c *fiber.Ctx) error

func RemoveTeamMember

func RemoveTeamMember(c *fiber.Ctx) error

func RenderLive

func RenderLive(c *fiber.Ctx) error

func RenderVersion

func RenderVersion(c *fiber.Ctx) error

func ResetPassword

func ResetPassword(c *fiber.Ctx) error

func ResolveJoinRequest

func ResolveJoinRequest(c *fiber.Ctx) error

ResolveJoinRequest allows an authorized admin to approve or reject a pending request.

func RestorePrompt

func RestorePrompt(c *fiber.Ctx) error

func SendPasswordResetEmail

func SendPasswordResetEmail(email, code string) error

func SendVerificationEmail

func SendVerificationEmail(email, code string) error

func SetTag

func SetTag(c *fiber.Ctx) error

func TriggerPasswordReset

func TriggerPasswordReset(c *fiber.Ctx) error

func TriggerVerification

func TriggerVerification(c *fiber.Ctx) error

func UpdateMe

func UpdateMe(c *fiber.Ctx) error

func UpdateOrg

func UpdateOrg(c *fiber.Ctx) error

func UpdatePrompt

func UpdatePrompt(c *fiber.Ctx) error

func UpdatePromptPayload

func UpdatePromptPayload(c *fiber.Ctx) error

func UpdateTeam

func UpdateTeam(c *fiber.Ctx) error

func UpdateTeamMemberRole

func UpdateTeamMemberRole(c *fiber.Ctx) error

func UpdateVersion

func UpdateVersion(c *fiber.Ctx) error

func Verify

func Verify(c *fiber.Ctx) error

Types

This section is empty.

Jump to